@@ -142,6 +142,8 @@ enum MS_TOKEN_SOURCES { MS_FILE_TOKENS = 0, MS_STRING_TOKENS };
 
 #define FORCE 1098
 #define TOLERANCEUNITS 1099
+#define IDENTIFY 1103
+#define CLASSAUTO 1104
 #define CHARACTER 1100
 
 #define CONNECTION 1101
@@ -169,6 +171,8 @@ enum MS_TOKEN_SOURCES { MS_FILE_TOKENS = 0, MS_STRING_TOKENS };
 
 #define STYLEITEM 1124
 
+#define FALLBACK 1125
+
 #define TITLE 1126
 
 #define LINECAP 1127
